"""
Logging configuration module
"""

import logging
from logging.config import dictConfig

from portal.tools import paths

FORMATTERS = {
    'verbose': {
        'format': '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
    },

    'simple': {
        'format': '%(levelname)s %(message)s'
    },
    'colored_console': {
        '()': 'coloredlogs.ColoredFormatter',
        'format': "%(asctime)s - %(name)s - %(levelname)s - %(message)s", 'datefmt': '%H:%M:%S'
    },
}

HANDLERS = {
    'console': {
        'level': 'DEBUG',
        'class': 'logging.StreamHandler',
        'formatter': 'colored_console'
    },
    'file': {
        'level': 'DEBUG',
        'class': 'logging.handlers.RotatingFileHandler',
        'formatter': 'verbose',
        'filename': str(paths.LOG_DIR / 'portal.log'),
        'maxBytes': 500000,
        'backupCount': 5
    }
}

LOGGERS = {
    'portal': {'handlers': ['console', 'file'], 'level': 'DEBUG', 'propagate': True},
    'tests': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': True},
    'management': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': True},
    'app': {'handlers': ['console'], 'level': 'INFO', 'propagate': True},
    'storage': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': True},
}

LOGGING_CONF = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': FORMATTERS,
    'handlers': HANDLERS,
    'loggers': LOGGERS,
}


def load_config(conf_type=None):
    """Loads config based on the config type
    Args:
        conf_type(str): Config type available (dev, test, prod)

    """
    if conf_type is not None:
        print("Not implemented yet!")
    dictConfig(LOGGING_CONF)


def get_logger(*args, **kwargs):
    logger = logging.getLogger(*args, **kwargs)
    return logger
