"""
Reviews service
"""

import logging
from typing import List

from portal.database.models import Review, ReviewItem, Submission, User
from portal.service.general import write_entity

log = logging.getLogger(__name__)


class ReviewService:
    def __init__(self, review: Review = None, submission: Submission = None):
        self._review = review
        self._submission = submission

    @property
    def review(self) -> Review:
        return self._review or self.submission.review

    @property
    def submission(self):
        return self._submission or self._review.submission

    def create_review_items(self, author: User, items: List[dict]) -> Review:
        """Creates review items for the review

        Args:
            author(User): Review's author
            items(List[dict]): Review items to append to the review

        Returns(Review): review instance with review items
        """
        for item in items:
            ReviewItem(user=author, review=self.review, file=item['file'], line=item['line'],
                       content=item['content'])
        log.info(f"Added review items {items} to review {self.review.id} "
                 f"for submission {self.submission.id}")
        write_entity(self.review)
        return self.review

    def create(self) -> Review:
        """Creates instance of the review

        Args:

        Returns(Review): Review instance
        """
        log.debug(f"[CREATE] Review for submission: {self.submission.id}")
        review = Review(submission=self.submission)
        write_entity(review)
        return review
