import pytest

from portal import logger
from portal.database.models import Course, User
from portal.service import permissions
log = logger.get_logger(__name__)


@pytest.fixture
def admin_user(app):
    return User.query.filter_by(username='admin').first()


@pytest.fixture
def student_user(app):
    return User.query.filter_by(username='student1').first()


@pytest.fixture
def course(app):
    return Course.query.filter_by(codename='testcourse1').first()


def test_project_list_with_admin_permissions(course, admin_user):
    service = permissions.PermissionsService(admin_user, course)
    assert service.check.client(['view_course_full'])


def test_project_list_with_non_admin_permissions(student_user, course):
    service = permissions.PermissionsService(student_user, course)
    assert not service.check.client(['view_course_full'])


def test_project_list_with_non_admin_permissions_limited(student_user, course):
    service = permissions.PermissionsService(student_user, course)
    assert service.check.client(['view_course_limited'])
